# jarvisfileopen

Libreria Python per aprire file in modo semplicissimo e veloce, usando:

```python
import jarvisfileopen
jarvisfileopen.open = "C:\\Users\\tuo-nome\\Desktop\\file.pdf"
```

Creato da Mattia Leoni il 22.07.2025
